pyLDLE2
========

pyLDLE2 provides an implementation of our manifold learning algorithm [LDLE](http://jmlr.org/papers/v22/21-0131.html) and several variations of it.


Installation
------------

Install pyLDLE2 by running:

    python3 -m pip install pyLDLE2

Contribute
----------

- Issue Tracker: github.com/chiggum/pyLDLE2/issues
- Source Code: github.com/chiggum/pyLDLE2

Documentation
----------
https://pyldle2.readthedocs.io/en/latest/


Citation
----------
```
@article{JMLR:v22:21-0131,
  author  = {Dhruv Kohli and Alexander Cloninger and Gal Mishne},
  title   = {LDLE: Low Distortion Local Eigenmaps},
  journal = {Journal of Machine Learning Research},
  year    = {2021},
  volume  = {22},
  number  = {282},
  pages   = {1-64},
  url     = {http://jmlr.org/papers/v22/21-0131.html}
}
```